@@ -24,7 +24,6 @@
 #' @export
 OptimInstanceAsync = R6Class("OptimInstanceAsync",
   inherit = OptimInstance,
-  cloneable = FALSE,
   public = list(
 
     rush = NULL,
@@ -74,7 +73,7 @@ OptimInstanceAsync = R6Class("OptimInstanceAsync",
     #' @param ... (ignored).
     print = function(...) {
       super$print()
-      catf(str_indent("* Workers:", self$rush$n_workers))
+      cat_cli(cli_li("Workers: {.val {self$rush$n_workers}}"))
     },
 
     #' @description
