@@ -7,7 +7,7 @@ old_opts = options(
 # https://github.com/HenrikBengtsson/Wishlist-for-R/issues/88
 old_opts = lapply(old_opts, function(x) if (is.null(x)) FALSE else x)
 
-lg_bbotk = lgr::get_logger("bbotk")
+lg_bbotk = lgr::get_logger("mlr3/bbotk")
 lg_rush = lgr::get_logger("rush")
 
 old_threshold_bbotk = lg_bbotk$threshold
